@@ -12,7 +12,10 @@ from ..classification import classify, user_classfile
 try:
     from . import anatomical
     CELLPOSE_INSTALLED = True
-except:
+except Exception as e:
+    print('Warning: cellpose did not import')
+    print(e)
+    print('cannot use anatomical mode, but otherwise suite2p will run normally')
     CELLPOSE_INSTALLED = False
 
 
@@ -46,7 +49,7 @@ def detect(ops, classfile=None):
 
     t0 = time.time()
     if ops.get('anatomical_only', 0) and not CELLPOSE_INSTALLED:
-        print('~~~ tried anatomical but failed, install cellpose to use: ~~~')
+        print('~~~ tried to import cellpose to run anatomical but failed, install with: ~~~')
         print('$ pip install cellpose')
 
     if ops.get('anatomical_only', 0) > 0 and CELLPOSE_INSTALLED:
@@ -123,7 +126,7 @@ def select_rois(ops: Dict[str, Any], mov: np.ndarray, dy: int, dx: int, Ly: int,
         else:
             iscell = classify(stat=stat, classfile=classfile)
         np.save(Path(ops['save_path']).joinpath('iscell.npy'), iscell)
-        ic = (iscell[:,0]>ops['preclassify']).flatten().astype(np.bool)
+        ic = (iscell[:,0]>ops['preclassify']).flatten().astype('bool')
         stat = stat[ic]
         print('Preclassify threshold %0.2f, %d ROIs removed' % (ops['preclassify'], (~ic).sum()))
             
