@@ -2,7 +2,7 @@ import os
 import time
 
 import numpy as np
-from numba import prange, njit, jit
+from numba import prange, njit, jit, int64, float32
 from numba.typed import List
 from scipy import stats, signal
 from .masks import create_masks
@@ -62,15 +62,19 @@ def extract_traces(ops, cell_masks, neuropil_masks, reg_file):
 
     nimgbatch = int(nimgbatch)
     
-    cell_ipix = [cell_mask[0].astype(np.int64) for cell_mask in cell_masks]
-    cell_lam = [cell_mask[1].astype(np.float32) for cell_mask in cell_masks]
+    cell_ipix, cell_lam = List(), List()
+    [cell_ipix.append(cell_mask[0].astype(np.int64)) for cell_mask in cell_masks]
+    [cell_lam.append(cell_mask[1].astype(np.float32)) for cell_mask in cell_masks]
+
+    #cell_ipix = [int64(cell_mask[0]) for cell_mask in cell_masks]
+    #cell_lam = [float32(cell_mask[1]) for cell_mask in cell_masks]
 
     if neuropil_masks is not None:
+        neuropil_ipix = List()
         if isinstance(neuropil_masks, np.ndarray) and neuropil_masks.shape[1] == Ly*Lx:
-            neuropil_masks = [np.nonzero(neuropil_mask)[0] for neuropil_mask in neuropil_masks]
+            [neuropil_ipix.append(np.nonzero(neuropil_mask)[0]) for neuropil_mask in neuropil_masks]
         else:
-            neuropil_masks = [neuropil_mask.astype(np.int64) for neuropil_mask in neuropil_masks]
-        neuropil_ipix = neuropil_masks
+            [neuropil_ipix.append(neuropil_mask.astype(np.int64)) for neuropil_mask in neuropil_masks]
         neuropil_npix = np.array([len(neuropil_ipixi) for neuropil_ipixi in neuropil_ipix]).astype(np.float32)
     else:
         neuropil_ipix = None
@@ -87,9 +91,9 @@ def extract_traces(ops, cell_masks, neuropil_masks, reg_file):
         # extract traces and neuropil
         
         # (WITHOUT NUMBA)
-        # for n in range(ncells):
+        #for n in range(ncells):
         #    F[n,inds] = np.dot(data[:, cell_masks[n][0]], cell_masks[n][1])
-        # Fneu[:,inds] = np.dot(neuropil_masks , data.T)
+        #Fneu[:,inds] = np.dot(neuropil_masks , data.T)
 
         # WITH NUMBA
         F[:,inds] = matmul_traces(Fi, data, cell_ipix, cell_lam)
@@ -103,7 +107,7 @@ def extract_traces(ops, cell_masks, neuropil_masks, reg_file):
 
 @njit(parallel=True)
 def matmul_traces(Fi, data, cell_ipix, cell_lam):
-    ncells = len(cell_ipix)
+    ncells = Fi.shape[0]
     for n in prange(ncells):
         Fi[n] = np.dot(data[:, cell_ipix[n]], cell_lam[n])
     return Fi
@@ -133,7 +137,7 @@ def extract_traces_from_masks(ops, cell_masks, neuropil_masks):
     return F, Fneu, F_chan2, Fneu_chan2, ops
 
 def create_masks_and_extract(ops, stat, cell_masks=None, neuropil_masks=None):
-    """ creates masks, computes fluorescence, and saves stat, F, and Fneu to \*.npy
+    """ creates masks, computes fluorescence, and saves stat, F, and Fneu to .npy
 
     Parameters
     ----------------
